from xml.etree.ElementTree import Element, SubElement, tostring
from argparse import ArgumentParser


class Phoebus(object):
    def __init__(self):
        pass



if __name__ == '__main__':
    p = Phoebus()
