""" Phoebus XML Generator

This package contains sub-packages:

test_widget -- Creates individual Phoebus "test_widget"

screen -- Builds complete Phoebus screens from test_widget

"""

__all__ = ["widget", "screen"]